import json

def process_jsonl_file(input_file, output_file):
    """
    处理包含两种格式的jsonl文件：
    1. 有"主要内容"字段的数据：保留指定字段并重命名
    2. 其他格式数据：原样保留
    
    :param input_file: 输入文件路径
    :param output_file: 输出文件路径
    """
    processed_count = 0
    skipped_count = 0
    
    with open(input_file, 'r', encoding='utf-8') as infile, \
         open(output_file, 'w', encoding='utf-8') as outfile:
        
        for line in infile:
            try:
                data = json.loads(line.strip())
                
                # 检查是否有"主要内容"字段
                if '主要内容' in data:
                    # 创建新数据对象，只保留指定字段
                    new_data = {
                        '工单编号': data.get('工单编号'),
                        'data': data.get('主要内容'),  # 重命名字段
                        'ins_tag_label': data.get('ins_tag_label'),
                        'cluster_center': data.get('cluster_center')
                    }
                    
                    # 写入处理后的数据
                    outfile.write(json.dumps(new_data, ensure_ascii=False) + '\n')
                    processed_count += 1
                else:
                    # 没有"主要内容"字段的数据原样写入
                    outfile.write(line)
                    skipped_count += 1
                    
            except json.JSONDecodeError:
                print(f"警告：跳过无法解析的行: {line.strip()}")
                skipped_count += 1
                continue
    
    print(f"处理完成！共处理 {processed_count} 条有'主要内容'的数据")
    print(f"保留原样 {skipped_count} 条其他格式数据")
    print(f"结果已保存到 {output_file}")

# 使用示例
input_file = "./merged_result_for_more_test.jsonl"  # 替换为你的输入文件路径
output_file = "./12345_merged_resul.jsonl"  # 输出文件路径
process_jsonl_file(input_file, output_file)